==> escapework-manager-0.3.0-965592.tar: src/EscapeWork/Manager/Controller/UserController.php <==
<?php namespace EscapeWork\Manager\Controller;

use View;
use Input;
use Redirect;
use Msg;
use Config;
use Auth;
use Request;
use App;
use EscapeWork\Manager\Model\User;

class UserController extends ManagerController
{

    public function __construct()
    {   
        $this->user = App::make('UserRepository');
        $this->role = App::make('RoleRepository');

        $this->enableDefaultFilters('usuarios');
    }

    public function index()
    {
        $view        = View::make('manager::users.index');
        $view->users = $this->user->get();

        return $view;
    }

    public function create()
    {
        Msg::setInfo('Inserindo um novo usuário');

        $this->user->fill(Input::old());

        $view       = View::make('manager::users.form');
        $view->user = $this->user;
        $view->role = $this->role;
        $view->edit = false;
        $view->extraFields = Config::get('manager::extra_fields.User');

        return $view;
    }

    public function store()
    {
        $fields = Input::all();

        if (! $this->user->validate($fields)) {
            return Redirect::route('manager.users.create')
                    ->withInput()
                    ->with('errors', User::$messages);
        }

        $this->user->fill($fields);
        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>' . $this->user->name . '</strong> foi inserido com sucesso!');
    }

    public function show($id)
    {
        if (Request::ajax()) {
            return $this->user->find($id);
        } else {
            return Redirect::to('manager.users.index');
        }
    }

    public function edit($id)
    {
        if (! $this->user = $this->user->find($id)) {
            return Redirect::to(Config::get('manager::url') . '/usuarios')
                    ->with('error', 'Usuário não encontrado');
        }

        Msg::setInfo('Editando o usuário <strong>'.$this->user->name.'</strong>');

        $view              = View::make('manager::users.form');
        $view->edit        = true;
        $view->user        = $this->user;
        $view->role        = $this->role;
        $view->extraFields = Config::get('manager::extra_fields.User');
        
        return $view;
    }

    public function update($id)
    {
        if (! $this->user = $this->user->find($id)) {
            return Redirect::to( Config::get('manager::url') . '/usuarios' )
                    ->with('error', 'Usuário não encontrado');
        }

        # forçando a validação a ignorar o id passado
        User::$validationRules['email']['unique'] .= ',email,' . $this->user->id;

        # validando
        $fields = Input::except('_method');

        if (! $this->user->validate($fields)) {
            return Redirect::route('manager.users.edit', $this->user->id)
                            ->withInput()
                            ->with('errors', User::$messages);
        }

        # atualizando no banco
        $this->user->fill($fields);
        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'. $this->user->name .'</strong> foi editado com sucesso!'); 
    }

    public function destroy($id)
    {
        if (! $this->user = $this->user->find($id)) {
            return Redirect::route('manager.users.index')
                    ->with('error', 'Usuário não encontrado');
        }

        # verificando se o usuário logado não está tentando se excluir
        if (Auth::check() && $this->user->id == Auth::user()->id) {
            return Redirect::route('manager.users.index')
                    ->with('error', '<strong>'.$this->user->name.'</strong>, não é possível excluir o seu próprio usuário');
        }

        $this->user->delete();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'.$this->user->name.'</strong> foi excluído com sucesso!');
    }
}

==> escapework-manager-0.4.0-9a43a3.tar: src/EscapeWork/Manager/Controller/UserController.php <==
<?php namespace EscapeWork\Manager\Controller;

use View;
use Input;
use Redirect;
use Msg;
use Config;
use Auth;
use Request;
use App;
use EscapeWork\Manager\Model\User;

class UserController extends ManagerController
{

    public function __construct()
    {   
        $this->user = App::make('UserRepository');
        $this->role = App::make('RoleRepository');

        $this->enableDefaultFilters('usuarios');
    }

    public function index()
    {
        $view        = View::make('manager::users.index');
        $view->users = $this->user->get();

        return $view;
    }

    public function create()
    {
        Msg::setInfo('Inserindo um novo usuário');

        $this->user->fill(Input::old());

        $view       = View::make('manager::users.form');
        $view->user = $this->user;
        $view->role = $this->role;
        $view->edit = false;
        $view->extraFields = Config::get('manager::extra_fields.User');

        return $view;
    }

    public function store()
    {
        $fields = Input::all();
        $this->user->fill($fields);
        
        if (! $this->user->validate()) {
            return Redirect::route('manager.users.create')
                    ->withInput()
                    ->with('errors', User::$messages);
        }

        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>' . $this->user->name . '</strong> foi inserido com sucesso!');
    }

    public function show($id)
    {
        if (Request::ajax()) {
            return $this->user->find($id);
        } else {
            return Redirect::to('manager.users.index');
        }
    }

    public function edit($id)
    {
        if (! $this->user = $this->user->find($id)) {
            return Redirect::to(Config::get('manager::url') . '/usuarios')
                    ->with('error', 'Usuário não encontrado');
        }

        Msg::setInfo('Editando o usuário <strong>'.$this->user->name.'</strong>');

        $view              = View::make('manager::users.form');
        $view->edit        = true;
        $view->user        = $this->user;
        $view->role        = $this->role;
        $view->extraFields = Config::get('manager::extra_fields.User');
        
        return $view;
    }

    public function update($id)
    {
        if (! $this->user = $this->user->find($id)) {
            return Redirect::to( Config::get('manager::url') . '/usuarios' )
                    ->with('error', 'Usuário não encontrado');
        }

        # forçando a validação a ignorar o id passado
        User::$validationRules['email']['unique'] .= ',email,' . $this->user->id;

        # validando
        $fields = Input::except('_method');
        $this->user->fill($fields);

        if (! $this->user->validate()) {
            return Redirect::route('manager.users.edit', $this->user->id)
                            ->withInput()
                            ->with('errors', User::$messages);
        }

        # atualizando no banco
        $this->user->save();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'. $this->user->name .'</strong> foi editado com sucesso!'); 
    }

    public function destroy($id)
    {
        if (! $this->user = $this->user->find($id)) {
            return Redirect::route('manager.users.index')
                    ->with('error', 'Usuário não encontrado');
        }

        # verificando se o usuário logado não está tentando se excluir
        if (Auth::check() && $this->user->id == Auth::user()->id) {
            return Redirect::route('manager.users.index')
                    ->with('error', '<strong>'.$this->user->name.'</strong>, não é possível excluir o seu próprio usuário');
        }

        $this->user->delete();

        return Redirect::route('manager.users.index')
                ->with('message', 'O usuário <strong>'.$this->user->name.'</strong> foi excluído com sucesso!');
    }
}
